summaryrefslogtreecommitdiff
path: root/IOFileClass/FileManIOFile.hpp
diff options
context:
space:
mode:
authormanzerbredes <loic.guegan_secondary@yahoo.fr>2015-03-11 17:21:24 +0400
committermanzerbredes <loic.guegan_secondary@yahoo.fr>2015-03-11 17:21:24 +0400
commit34b47f8e08eff519f6c8372f2e4ce5b24267614c (patch)
tree4aebab48876d857eb24117a104c9348c508f5d82 /IOFileClass/FileManIOFile.hpp
parentecda75a273c653eeb42bd0449831a250433e05f0 (diff)
Arrange FileManIOFile class
Diffstat (limited to 'IOFileClass/FileManIOFile.hpp')
-rw-r--r--IOFileClass/FileManIOFile.hpp22
1 files changed, 20 insertions, 2 deletions
diff --git a/IOFileClass/FileManIOFile.hpp b/IOFileClass/FileManIOFile.hpp
index 310ded9..7013b27 100644
--- a/IOFileClass/FileManIOFile.hpp
+++ b/IOFileClass/FileManIOFile.hpp
@@ -50,12 +50,16 @@ class FileManIOFile {
*/
void read(std::string key);
+
/**
* @brief Read encrypted file.
*
* @param key : key to encrypt data
+ * @param data : data to write
*
- * Save data to "filename" attribute.
+ * Write the file with or without key
+ * To write data without key, you need to read it before (to save the key
+ * in attribute key;
*
*/
void write(std::string key, std::string data);
@@ -63,6 +67,20 @@ class FileManIOFile {
/**
+ * @brief Write data in encrypted file.
+ *
+ * @param data : data to write (for MD5)
+ * @param dataEncrypted : data to write
+ *
+ * Write encryptedData to filename
+ *
+ */
+ void writeRoutine(std::string data, std::string dataEncrypted);
+
+
+
+
+ /**
* @brief True if file fully decrypted.
*
* Return "readable" attribute.
@@ -50,12 +50,16 @@ class FileManIOFile {
/**
- * @brief Read encrypted file.
+ * @brief Write data in encrypted file.
*
* @param key : key to encrypt data